@@ -1,23 +1,27 @@
 revise.ispd <- function(tpm=NULL,gamma=NULL,lns=NULL,cis=TRUE) {
 # Function revise.ispd.  To revise the initial state probability
 # distribution
+# Note: "cis" <--> constant initial state probability distribution.
 
 if(cis) {
     if(is.null(tpm) + (is.null(gamma) & is.null(lns)) != 1)
     	stop(paste("When \"cis\" is TRUE either \"tpm\" should be given\n",
                    "OR \"gamma\" and \"lns\" should be given.\n"))
     
-# If ispd is taken to be the steady state distribution:
+# If ispd is taken to be the steady state distribution (i.e. if
+# tpm is provided):
     if(!is.null(tpm)) {
-    	eee   <- eigen(t(tpm))
-    	k <- match(1,round(eee$values,6))
-    	if(length(k) != 1) {
-    		cat('Problems with eigenvalues:\n')
-    		print(eee$values)
-    		stop()
-    	}
-    	v <- Re(eee$vectors[,k])
-        ispd <- v/sum(v)
+        eee <- eigen(t(tpm))
+        k   <- which(as.logical(match(round(eee$values,6),1,nomatch=0)))
+        if(length(k) == 1) {
+    	    v <- Re(eee$vectors[,k])
+            ispd <- v/sum(v)
+        } else {
+            whinge <- paste0("The ispd is undefined.  The",
+            " eigenvalues of\n","t(tpm) are ",
+            paste(eee$values,collapse=" "),".\n")
+            stop(whinge)
+        }
     } else {
     
 # Steady state not assumed:
